<?php
// BACKEND API URL COMPONENT
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: backendapiurl.inc.php 771 2012-08-27 18:06:10Z mguthrie $

require_once(dirname(__FILE__).'/../componenthelper.inc.php');

// respect the name
$backendapiurl_component_name="backendapiurl";

// run the initialization function
backendapiurl_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function backendapiurl_component_init(){
	global $backendapiurl_component_name;
	
	$args=array(

		// need a name
		COMPONENT_NAME => $backendapiurl_component_name,
		COMPONENT_VERSION => '1.0',
		// informative information
		COMPONENT_AUTHOR => "Nagios Enterprises, LLC",
		COMPONENT_DESCRIPTION => "Provides information on the URLs used to access the Nagios XI backend API.",
		COMPONENT_TITLE => "Backend API URL",

		// configuration function (optional)
		COMPONENT_CONFIGFUNCTION => "backendapiurl_component_config_func",
		);
		
	register_component($backendapiurl_component_name,$args);
	
	}
	



///////////////////////////////////////////////////////////////////////////////////////////
//CONFIG FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function backendapiurl_component_config_func($mode="",$inargs,&$outargs,&$result){
	global $backendapiurl_component_name;

	// initialize return code and output
	$result=0;
	$output="";
	
	//delete_option("backendapiurl_component_options");
	

	switch($mode){
		case COMPONENT_CONFIGMODE_GETSETTINGSHTML:
		
			// values passed to us
			$username=grab_array_var($inargs,"username","");
						
			$component_url=get_component_url_base($backendapiurl_component_name);
	

			// get list of users from the backend
			$args=array(
				"cmd" => "getusers",
				);
			$xmlusers=get_backend_xml_data($args);

			//print_r($xmlusers);
			
			$output='';
			
			$output.='
				<p>
				<b>Developers:</b> The Nagios XI backend API can be used to access current and historical information on monitored hosts and services for integration into third-party frontends.  In order to access XML data via the backend API you must pass a username and a backend ticket to identify yourself.  Without the proper credentials, no data is returned.
				</p>
				';
			
			$base_url=get_base_url();
			
			if($username!=""){
			
				$uid=get_user_id($username);
				if($uid==0)
					$backend_ticket="";
				else
					$backend_ticket=get_user_attr($uid,"backend_ticket");
				
				$output.='

				<div class="sectionTitle">Backend API URLs</div>
				
				<p>You can use the URLs below to fetch information from the Nagios XI backend API.  <b>Note:</b> It is important to retain the <em>username</em> and <em>ticket</em> query parameters.</p>
				
				<table class="standardtable">
				
				<tr>
				<th>Data Type</th>
				<th>URL</th>
				</tr>
				';
				
				$opts=array(
					"Current Host Status" => "gethoststatus",
					"Current Service Status" => "getservicestatus",
					"Current Program Status" => "getprogramstatus",
					"Current Program Performance" => "getprogramperformance",
					"System Statistics" => "getsysstat",
					"Log Entries" => "getlogentries",
					"State History" => "getstatehistory",
					"Comments" => "getcomments",
					"Scheduled Downtime" => "getscheduleddowntime",
					"Users" => "getusers",
					"Contact" => "getcontacts",
					"Hosts" => "gethosts",
					"Services" => "getservices",
					"Hostgroups" => "gethostgroups",
					"Servicegroups" => "getservicegroups",
					"Contactgroups" => "getcontactgroups",
					"Hostgroup Members" => "gethostgroupmembers",
					"Servicegroup Members" => "getservicegroupmembers",
					"Contactgroup Members" => "getcontactgroupmembers",
					);
					
				$x=0;
				foreach($opts as $desc => $urlopts){
					$x++;

					$output.='
				<tr>
				<td valign="top"><label>'.$desc.':</label></td>
				<td valign="top">
				<input type="text" size="80" name="url'.$x.'" value="'.$base_url.'backend/?cmd='.$urlopts.'&username='.htmlentities($username).'&ticket='.htmlentities($backend_ticket).'">
				</td>
				</tr>
				';
					}
				
				$output.='
				</table>
				';
				
				}
			
			$output.='

			<div class="sectionTitle">Account Selection</div>
			
			<p>Select the user account you would like to get backend API URLs for.</p>
				
			<table>

			<tr>
			<td valign="top"><label>User:</label></td>
			<td valign="top">
			<select name="username">
			<option value="">SELECT ONE</option>
			';
			
			if($xmlusers){
				foreach($xmlusers->user as $u){
					//print_r($u);
					
					$uid=get_user_id($u->username);
					
					$output.="<option value='".$u->username."' ".is_selected($username,strval($u->username)).">".$u->name." (".$u->username.")</option>\n";
					}
				}
	
			$output.='
			</select>
			</td>
			</tr>
			
			</table>
			';
		

			break;
			
		case COMPONENT_CONFIGMODE_SAVESETTINGS:
		
			$username=grab_array_var($inargs,"username");
			if($username==""){
				$result=1;
				$errmsg=array();
				$errmsg[]="Please select a username to obtain backend URL information.";
				$outargs[COMPONENT_ERROR_MESSAGES]=$errmsg;
				}
		
					
			// info messages
			$okmsg=array();
			$okmsg[]="Backend API URLs are shown below.";
			$outargs[COMPONENT_INFO_MESSAGES]=$okmsg;
			
			break;
		
		default:
			break;
			
		}
		
	return $output;
	}



?>